! Author: P.Videler
! Version: 0.9
! 
! (c) 1998 European Space Agency 
!
! Description: regionstat task for the XMM Science Analysis System
! 
! Comments:
! 
! Modifications: 
!  19991216  MBe  updated parameter interface
! 
! $Id: regionstats_mod.f90,v 1.12 1999/12/16 14:17:06 mbeijers Exp $
! 
module regionstats_mod

 use saslib
 use imagelib

 implicit none 

 private    ! change default to private
 public  :: regionstats

contains 

 ! ====================================================================
 subroutine regionstats
  ! ====================================================================
  use datafilter

  type(imagesDal_t)                 :: aa
  type(images_t),      pointer	:: image
  type(images_t),      target   :: xx_t
  integer                           :: nselect

  type(DataSetT)    :: eventsSet   
  type(TableT)      :: eventsTable 

  type(imageStat_t) :: s
  type(DataSetT)    :: statSet

  ! ----------
  ! Initialize 
  ! ----------

  call init(aa)      ! always needed for using imagesDal

  ! ---------------------------
  ! Get image pointers from DAL
  ! ---------------------------

  !image => getImages(aa, imageSetName  = stringParameter("image")  &
  !
  ! To avoid a problem with returning a pointer from a function we
  ! now return a 'target' and point to it later
  xx_t = getImages(aa, imageSetName  = stringParameter("image")  &
         , imageName     = stringParameter("image")  &
         , badpixSetName = stringParameter("badpix") &
         , badpixName    = stringParameter("badpix") &
         , weightSetName = stringParameter("weight") &
         , weightName    = stringParameter("weight") &
         )

  image => xx_t

  ! -----------------------------------
  ! Calculate statistics
  ! -----------------------------------

  if (booleanParameter('filter')) then

     call message(AppMsg,Sparse,"Statistics from via filtered event table")

     eventsSet = dataSet(stringParameter('events'), create)
     eventsTable = addImage2eventTable(image, eventsSet, &
         tblname=stringParameter('events'))

     call initFilter(stringParameter("filterexpression"))
     nselect = doSelect(eventsTable, &
          flagColumnName=stringParameter("filterflagcolumn") )

     s = imageStatistics(eventsTable) 

     call release(eventsTable)
     call release(eventsSet)

  else

     call message(AppMsg,Sparse,"Statistics from image")

     s = imageStatistics(image)

  end if

  if (verbosity(appMsg) >= verbose) call report(s)  ! print results to screen

  statSet = dataSet(stringParameter('statisticsset'), create)
  call store(s, statSet, tblname='stats' )    ! write to file     
  call release(statSet)

  ! ------------
  !   Clean up
  ! ------------

  call free(aa)
  call free(image)

 end subroutine regionstats

end module 








