 ! --------------------------------------------------------------------
program makeImage
 ! --------------------------------------------------------------------
 ! generate test images for radial

 use dal
 use types
 implicit none 

  type(DataSetT)        :: myset
  type(ArrayT)          :: myarray
  integer, parameter    :: ndata=10
  real(single), pointer :: pp(:,:), sigma(:,:)
  integer(int32), pointer ::  bad(:,:)


  myset = dataSet('testImages.ds', create) 

  ! ------------- images ----------

  ! create rectangular image
  myarray = addArray(myset, 'flat', real32, (/ ndata, ndata+1/) )

  pp => real32Array2Data(myarray)
  pp = 3.5_single                      ! flat data at 3.5
  call release(myarray)

  ! peak at center
  myarray = addArray(myset, 'peak1', real32, (/ ndata, ndata+1/) )
  pp => real32Array2Data(myarray)
  pp = 3.5_single                      ! flat data at 3.5
  pp(ndata/2, (ndata/2)+1) = 10.5_single   ! peak near center 10.5
  call release(myarray)


  ! ------------- badpix ----------
  !  row col bad
  myarray = addArray(myset, 'flat_badpix', integer32, (/ndata, ndata+1/) )
  bad => int32Array2Data(myarray)
  bad = 0                      ! all data points good
  bad(1,:) = 1                 ! row bad    
  bad(:,2) = 1                 ! col bad    
  call release(myarray)

  !  all good
  myarray = addArray(myset, 'badpix2', integer32, (/ndata, ndata+1/) )
  bad => int32Array2Data(myarray)
  bad = 0                      ! all data points good
  call release(myarray)

  !  all bad
  myarray = addArray(myset, 'badpix3', integer32, (/ndata, ndata+1/) )
  bad => int32Array2Data(myarray)
  bad = 1                      ! all points bad
  call release(myarray)

  ! ------------- sigma ----------

  ! constant sigma array
  myarray = addArray(myset, 'flat_weight', real32, (/ndata, ndata+1/) )
  sigma => real32Array2Data(myarray)
  sigma = 1_single          
  call release(myarray)

 ! sigma with zero's 
  myarray = addArray(myset, 'sigma0', real32, (/ndata, ndata+1/) )
  sigma => real32Array2Data(myarray)
  sigma = 1_single            ! all points equal weight
  sigma(1,:) = 0            ! note ieee exception when zero
  call release(myarray)

  ! -----------------------------------------------------------  

  call release(myset)

end program









